@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"net/http/httptest"
 	"os"
+	"reflect"
 	"regexp"
 	"strings"
 	"testing"
@@ -14,10 +15,10 @@ import (
 
 func TestKeyspaceStringParser(t *testing.T) {
 	tsts := []struct {
-		db                        string
-		stats                     string
-		keysTotal, keysEx, avgTTL float64
-		ok                        bool
+		db                                    string
+		stats                                 string
+		keysTotal, keysEx, keysCached, avgTTL float64
+		ok                                    bool
 	}{
 		{db: "xxx", stats: "", ok: false},
 		{db: "xxx", stats: "keys=1,expires=0,avg_ttl=0", ok: false},
@@ -28,20 +29,24 @@ func TestKeyspaceStringParser(t *testing.T) {
 		{db: "db3", stats: "keys=abcde,expires=0", ok: false},
 		{db: "db3", stats: "keys=213,expires=xxx", ok: false},
 		{db: "db3", stats: "keys=123,expires=0,avg_ttl=zzz", ok: false},
+		{db: "db3", stats: "keys=1,expires=0,avg_ttl=zzz,cached_keys=0", ok: false},
+		{db: "db3", stats: "keys=1,expires=0,avg_ttl=0,cached_keys=zzz", ok: false},
+		{db: "db3", stats: "keys=1,expires=0,avg_ttl=0,cached_keys=0,extra=0", ok: false},
 
-		{db: "db0", stats: "keys=1,expires=0,avg_ttl=0", keysTotal: 1, keysEx: 0, avgTTL: 0, ok: true},
+		{db: "db0", stats: "keys=1,expires=0,avg_ttl=0", keysTotal: 1, keysEx: 0, avgTTL: 0, keysCached: -1, ok: true},
+		{db: "db0", stats: "keys=1,expires=0,avg_ttl=0,cached_keys=0", keysTotal: 1, keysEx: 0, avgTTL: 0, keysCached: 0, ok: true},
 	}
 
 	for _, tst := range tsts {
-		if kt, kx, ttl, ok := parseDBKeyspaceString(tst.db, tst.stats); true {
+		if kt, kx, ttl, kc, ok := parseDBKeyspaceString(tst.db, tst.stats); true {
 
 			if ok != tst.ok {
 				t.Errorf("failed for: db:%s stats:%s", tst.db, tst.stats)
 				continue
 			}
 
-			if ok && (kt != tst.keysTotal || kx != tst.keysEx || ttl != tst.avgTTL) {
-				t.Errorf("values not matching, db:%s stats:%s   %f %f %f", tst.db, tst.stats, kt, kx, ttl)
+			if ok && (kt != tst.keysTotal || kx != tst.keysEx || kc != tst.keysCached || ttl != tst.avgTTL) {
+				t.Errorf("values not matching, db:%s stats:%s   %f %f %f %f", tst.db, tst.stats, kt, kx, kc, ttl)
 			}
 		}
 	}
@@ -103,6 +108,18 @@ func TestCommandStats(t *testing.T) {
 	deleteKeysFromDB(t, redisSixTwoAddr)
 }
 
+func TestLatencyStats(t *testing.T) {
+	redisSevenAddr := os.Getenv("TEST_REDIS7_URI")
+
+	// Since Redis v7 we should have extended latency stats (summary of command latencies)
+	e := getTestExporterWithAddr(redisSevenAddr)
+	setupDBKeys(t, redisSevenAddr)
+
+	want := map[string]bool{"latency_percentiles_usec": false}
+	commandStatsCheck(t, e, want)
+	deleteKeysFromDB(t, redisSevenAddr)
+}
+
 func commandStatsCheck(t *testing.T, e *Exporter, want map[string]bool) {
 	chM := make(chan prometheus.Metric)
 	go func() {
@@ -180,9 +197,9 @@ func TestClusterSlave(t *testing.T) {
 		}
 	}
 	hostReg, _ := regexp.Compile(`master_host="([0,1]?\d{1,2}|2([0-4][0-9]|5[0-5]))(\.([0,1]?\d{1,2}|2([0-4][0-9]|5[0-5]))){3}"`)
-	masterHost := hostReg.FindString(string(body))
+	masterHost := hostReg.FindString(body)
 	portReg, _ := regexp.Compile(`master_port="(\d+)"`)
-	masterPort := portReg.FindString(string(body))
+	masterPort := portReg.FindString(body)
 	for wantedKey, wantedVal := range map[string]int{
 		masterHost: 5,
 		masterPort: 5,
@@ -373,3 +390,68 @@ func TestParseErrorStats(t *testing.T) {
 	}
 
 }
+
+func Test_parseMetricsLatencyStats(t *testing.T) {
+	type args struct {
+		fieldKey   string
+		fieldValue string
+	}
+	tests := []struct {
+		name              string
+		args              args
+		wantCmd           string
+		wantPercentileMap map[float64]float64
+		wantErr           bool
+	}{
+		{
+			name:              "simple",
+			args:              args{fieldKey: "latency_percentiles_usec_ping", fieldValue: "p50=0.001,p99=1.003,p99.9=3.007"},
+			wantCmd:           "ping",
+			wantPercentileMap: map[float64]float64{50.0: 0.001, 99.0: 1.003, 99.9: 3.007},
+			wantErr:           false,
+		},
+		{
+			name:              "single-percentile",
+			args:              args{fieldKey: "latency_percentiles_usec_ping", fieldValue: "p50=0.001"},
+			wantCmd:           "ping",
+			wantPercentileMap: map[float64]float64{50.0: 0.001},
+			wantErr:           false,
+		},
+		{
+			name:              "empty",
+			args:              args{fieldKey: "latency_percentiles_usec_ping", fieldValue: ""},
+			wantCmd:           "ping",
+			wantPercentileMap: map[float64]float64{0: 0},
+			wantErr:           false,
+		},
+		{
+			name:              "invalid-percentile",
+			args:              args{fieldKey: "latency_percentiles_usec_ping", fieldValue: "p50=a"},
+			wantCmd:           "ping",
+			wantPercentileMap: map[float64]float64{},
+			wantErr:           true,
+		},
+		{
+			name:              "invalid prefix",
+			args:              args{fieldKey: "wrong_prefix_", fieldValue: "p50=0.001,p99=1.003,p99.9=3.007"},
+			wantCmd:           "",
+			wantPercentileMap: map[float64]float64{},
+			wantErr:           true,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			gotCmd, gotPercentileMap, err := parseMetricsLatencyStats(tt.args.fieldKey, tt.args.fieldValue)
+			if (err != nil) != tt.wantErr {
+				t.Errorf("test %s. parseMetricsLatencyStats() error = %v, wantErr %v", tt.name, err, tt.wantErr)
+				return
+			}
+			if gotCmd != tt.wantCmd {
+				t.Errorf("parseMetricsLatencyStats() gotCmd = %v, want %v", gotCmd, tt.wantCmd)
+			}
+			if !reflect.DeepEqual(gotPercentileMap, tt.wantPercentileMap) {
+				t.Errorf("parseMetricsLatencyStats() gotPercentileMap = %v, want %v", gotPercentileMap, tt.wantPercentileMap)
+			}
+		})
+	}
+}
